@@ -4,11 +4,14 @@ https://github.com/nvladimus/npy2bdv
 #TODO: pass pyramidal layer to napari
 ##use ilevel parameter in read_view to access different subsamples/pyramids
 #pass a list of images with different resolution for pyramid; use is_pyramid=True flag in napari.add_image
+, however pyramidal support for 3D not available yet
 """
 
 import dask.array as da
 import dask.delayed as delayed
 import os 
+import numpy as np
+
 def napari_get_reader(path):
     """Check if file ends with h5 and returns reader function if true
     Parameters
@@ -37,7 +40,7 @@ def bdv_h5_reader(path):
     
     os.environ["HDF5_USE_FILE_LOCKING"] = "FALSE"
     
-    print(path)
+    #print(path)
     import npy2bdv
     h5_file = npy2bdv.npy2bdv.BdvEditor(path)
 
@@ -46,14 +49,39 @@ def bdv_h5_reader(path):
     #get dimensions of first image
     first_timepoint = h5_file.read_view(time=0,channel=0)
 
-    for time in range(h5_file.ntimes):
-        for ch in range(h5_file.nchannels):         
-            image = da.from_delayed(
-                        delayed(h5_file.read_view)(time=time,channel=ch), shape=first_timepoint.shape, dtype=first_timepoint.dtype
-                    )
-            img.append(image)
-           
-    images = da.stack(img)
+    #Threshold to figure out when to use out-of-memory loading/dask 
+    #Got the idea from napari-aicsimageio 
+    #https://github.com/AllenCellModeling/napari-aicsimageio/blob/22934757c2deda30c13f39ec425343182fa91a89/napari_aicsimageio/core.py#L222
+    mem_threshold_bytes = 4e9
+    mem_per_threshold = 0.3
+    
+    from psutil import virtual_memory
+    
+    file_size = os.path.getsize(path)
+    avail_mem = virtual_memory().available
+
+    #if file size <30% of available memory and <4GB, open 
+    if file_size<=mem_per_threshold*avail_mem and file_size<mem_threshold_bytes:
+        in_memory=True
+    else:
+        in_memory=False
+    
+    if in_memory:
+        for time in range(h5_file.ntimes):
+            for ch in range(h5_file.nchannels):
+                image = h5_file.read_view(time=time,channel=ch)
+                img.append(image)
+        images=np.stack(img)
+        
+    else:
+        for time in range(h5_file.ntimes):
+            for ch in range(h5_file.nchannels):         
+                image = da.from_delayed(
+                            delayed(h5_file.read_view)(time=time,channel=ch), shape=first_timepoint.shape, dtype=first_timepoint.dtype
+                        )
+                img.append(image)
+            
+        images = da.stack(img)
 
     
     # optional kwargs for the corresponding viewer.add_* method
